@@ -4,4 +4,4 @@ from .models import InstalacaoAtivo
 
 @admin.register(InstalacaoAtivo)
 class InstalacaoAtivoAdmin(admin.ModelAdmin):
-    list_display = ('id', 'comments')
+    list_display = ('id')
