@@ -9,7 +9,7 @@ class ActivityOptions(models.TextChoices):
 
 class InstalacaoAtivo(models.Model):
 
-    comments = models.CharField(max_length=200) # comments
+    comments = models.CharField(max_length=200)
     atv_data = models.DateField(default=date.today)
     reg_atv = models.DateTimeField(auto_now_add=True)
     actor_id = models.ManyToManyField('Actor')
